# Projeto: Pacote de Processamento de Imagens

### Curso: Python para Ciência de Dados - Digital Innovation One

[(clique aqui para ver o meu perfil na plataforma)](https://web.digitalinnovation.one/users/leo_he_martins)

#### Tecnologia: Python

#### Data: 23/09/2022

O pacote "image_processing-test" é usado para:

- Módulo "Processing":
  - Correspondência de histograma;
  - Similaridade estrutural;
  - Redimensionar imagem;

- Módulo "Utils":
  - Ler imagem;
  - Salvar imagem;
  - Plotar imagem;
  - Resultado do gráfico;
  - Plotar histograma;

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install package_name
```

## Author
Leonardo Henrique Martins

## License
[MIT](https://choosealicense.com/licenses/mit/)

### Aqui o objetivo não é utilizar o projeto da Karina para postar em meu perfil do Pypi pessoal, visto que o projeto é dela. Ainda não tenho nenhum projeto que possa ser utilizado como pacote.

### No entanto, tenha em mente que o Test Pypi, como o próprio nome diz, é apenas um ambiente de testes. Para que o projeto esteja disponível como um pacote para ser usado publicamente, é necessário hospedá-lo no site oficial do Pypi.